## Description

[Provide a brief description of the changes introduced by this merge request.]

## Related Issues

[Cite any related issues or feature requests that are addressed or resolved by this merge request. Use the gitlab syntax for linking issues, for example, `fixes #123` or `closes #123`.]

## Type of Change

- Change 1
- Change 2

## Potential side effects

[Describe any potential side effects or risks of merging this MR.]

## Screenshots / GIFs (if applicable)

[Include any relevant screenshots or GIFs to showcase the changes made.]

## Additional Comments

[Add any additional comments or information that may be helpful for reviewers.]

## Definition of Done
- [ ] Documentation is up-to-date.

